@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2024 Chris Caron <lead2gold@gmail.com>
+# Copyright (C) 2025 Chris Caron <lead2gold@gmail.com>
 # All rights reserved.
 #
 # This code is licensed under the MIT License.
@@ -37,7 +37,7 @@ from datetime import datetime, timezone, timedelta
 import time
 import hashlib
 from .common import PersistentStoreMode, PERSISTENT_STORE_MODES
-from .utils import path_decode
+from .utils.disk import path_decode
 from .logger import logger
 
 # Used for writing/reading time stored in cache file
