@@ -2,7 +2,7 @@
 # BSD 2-Clause License
 #
 # Apprise - Push Notification Library.
-# Copyright (c) 2024, Chris Caron <lead2gold@gmail.com>
+# Copyright (c) 2025, Chris Caron <lead2gold@gmail.com>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -64,9 +64,7 @@ from ..common import NotifyType
 from ..common import NotifyImageSize
 from ..common import NotifyFormat
 from ..common import PersistentStoreMode
-from ..utils import parse_bool
-from ..utils import parse_list
-from ..utils import validate_regex
+from ..utils.parse import parse_bool, parse_list, validate_regex
 from ..locale import gettext_lazy as _
 from ..attachment.base import AttachBase
 
