@@ -2,7 +2,7 @@
 # BSD 2-Clause License
 #
 # Apprise - Push Notification Library.
-# Copyright (c) 2024, Chris Caron <lead2gold@gmail.com>
+# Copyright (c) 2025, Chris Caron <lead2gold@gmail.com>
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -52,10 +52,8 @@ import requests
 from json import dumps
 from ..base import NotifyBase
 from ...common import NotifyType
-from ...utils import validate_regex
-from ...utils import parse_list
-from ...utils import parse_bool
-from ...utils import dict_full_update
+from ...utils.parse import validate_regex, parse_list, parse_bool
+from ...utils.logic import dict_full_update
 from ...common import NotifyImageSize
 from ...apprise_attachment import AppriseAttachment
 from ...locale import gettext_lazy as _
